Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(85)

Unified Diff: third_party/libxml/src/uri.c

Issue 2797923004: Improve XML serialization, URI parsing, and XPath node set processing. (Closed)
Patch Set: Rebase. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/libxml/src/parser.c ('k') | third_party/libxml/src/valid.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/libxml/src/uri.c
diff --git a/third_party/libxml/src/uri.c b/third_party/libxml/src/uri.c
index 2bd5720de97ca09277141be181d05ff2fe1a2e5a..4b24b1365a01ee18a32488d76b140189634582fc 100644
--- a/third_party/libxml/src/uri.c
+++ b/third_party/libxml/src/uri.c
@@ -12,6 +12,7 @@
#include "libxml.h"
#include <string.h>
+#include <limits.h>
#include <libxml/xmlmemory.h>
#include <libxml/uri.h>
@@ -334,7 +335,7 @@ xmlParse3986Port(xmlURIPtr uri, const char **str)
cur++;
}
if (uri != NULL)
- uri->port = port & INT_MAX; /* port value modulo INT_MAX+1 */
+ uri->port = port & USHRT_MAX; /* port value modulo USHRT_MAX+1 */
*str = cur;
return(0);
}
« no previous file with comments | « third_party/libxml/src/parser.c ('k') | third_party/libxml/src/valid.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698